import { blockquote, bold, bulletList, code, heading, history, italic, link, orderedList, paragraph, } from '@bangle.dev/base-components';
import { PluginKey } from '@bangle.dev/pm';
import { useEditorViewContext } from '@bangle.dev/react';
import { filter, rafCommandExec } from '@bangle.dev/utils';
import PropTypes from 'prop-types';
import React, { useCallback } from 'react';
import { defaultKeys as floatingMenuKeys, focusFloatingMenuInput, toggleLinkSubMenu, } from './floating-menu';
import { MenuButton } from './Icon';
import * as Icons from './Icons';
const { defaultKeys: orderedListKeys, queryIsOrderedListActive, toggleOrderedList, } = orderedList;
const { defaultKeys: italicKeys, queryIsItalicActive, toggleItalic } = italic;
const { defaultKeys: historyKeys, undo, redo } = history;
const { defaultKeys: boldKeys, queryIsBoldActive, toggleBold } = bold;
const { defaultKeys: codeKeys, queryIsCodeActive, toggleCode } = code;
const { defaultKeys: paragraphKeys, queryIsTopLevelParagraph, convertToParagraph, } = paragraph;
const { defaultKeys: headingKeys, queryIsHeadingActive, toggleHeading, } = heading;
const { createLink, queryIsLinkActive } = link;
const { defaultKeys: bulletListKeys, queryIsBulletListActive, queryIsTodoListActive, toggleBulletList, toggleTodoList, } = bulletList;
export function BoldButton({ hint = 'Bold\n' + boldKeys.toggleBold, hintPos = 'top', children = React.createElement(Icons.BoldIcon, null), ...props }) {
    const view = useEditorViewContext();
    const onSelect = useCallback((e) => {
        e.preventDefault();
        if (toggleBold()(view.state, view.dispatch, view)) {
            if (view.dispatch) {
                view.focus();
            }
        }
    }, [view]);
    return (React.createElement(MenuButton, { ...props, hintPos: hintPos, onMouseDown: onSelect, hint: hint, isActive: queryIsBoldActive()(view.state), isDisabled: !view.editable || !toggleBold()(view.state) }, children));
}
export function BlockquoteButton({ hint = 'Wrap in Blockquote\n' + blockquote.defaultKeys.wrapIn, hintPos = 'top', children = React.createElement(Icons.BlockquoteIcon, null), ...props }) {
    const view = useEditorViewContext();
    const onSelect = useCallback((e) => {
        e.preventDefault();
        if (blockquote.commands.wrapInBlockquote()(view.state, view.dispatch, view)) {
            if (view.dispatch) {
                view.focus();
            }
        }
    }, [view]);
    return (React.createElement(MenuButton, { ...props, hintPos: hintPos, onMouseDown: onSelect, hint: hint, isActive: blockquote.commands.queryIsBlockquoteActive()(view.state), isDisabled: !view.editable || !blockquote.commands.wrapInBlockquote()(view.state) }, children));
}
export function ItalicButton({ hint = 'Italic\n' + italicKeys.toggleItalic, hintPos = 'top', children = React.createElement(Icons.ItalicIcon, null), ...props }) {
    const view = useEditorViewContext();
    const onSelect = useCallback((e) => {
        e.preventDefault();
        if (toggleItalic()(view.state, view.dispatch, view)) {
            if (view.dispatch) {
                view.focus();
            }
        }
    }, [view]);
    return (React.createElement(MenuButton, { ...props, hintPos: hintPos, onMouseDown: onSelect, hint: hint, isActive: queryIsItalicActive()(view.state), isDisabled: !view.editable || !toggleItalic()(view.state) }, children));
}
export function UndoButton({ hint = 'Undo\n' + historyKeys.undo, hintPos = 'top', children = React.createElement(Icons.UndoIcon, null), ...props }) {
    const view = useEditorViewContext();
    const onSelect = useCallback((e) => {
        e.preventDefault();
        if (undo()(view.state, view.dispatch)) {
            if (view.dispatch) {
                view.focus();
            }
        }
    }, [view]);
    return (React.createElement(MenuButton, { ...props, hintPos: hintPos, onMouseDown: onSelect, hint: hint, isDisabled: !view.editable || !undo()(view.state) }, children));
}
export function RedoButton({ hint = 'Redo\n' + historyKeys.redo, hintPos = 'top', children = React.createElement(Icons.RedoIcon, null), ...props }) {
    const view = useEditorViewContext();
    const onSelect = useCallback((e) => {
        e.preventDefault();
        if (redo()(view.state, view.dispatch)) {
            if (view.dispatch) {
                view.focus();
            }
        }
    }, [view]);
    return (React.createElement(MenuButton, { ...props, hintPos: hintPos, onMouseDown: onSelect, hint: hint, isDisabled: !view.editable || !redo()(view.state) }, children));
}
export function CodeButton({ hint = 'Code\n' + codeKeys.toggleCode, hintPos = 'top', children = React.createElement(Icons.CodeIcon, null), ...props }) {
    const view = useEditorViewContext();
    const onSelect = useCallback((e) => {
        e.preventDefault();
        if (toggleCode()(view.state, view.dispatch, view)) {
            if (view.dispatch) {
                view.focus();
            }
        }
    }, [view]);
    return (React.createElement(MenuButton, { ...props, hintPos: hintPos, onMouseDown: onSelect, hint: hint, isActive: queryIsCodeActive()(view.state), isDisabled: !view.editable || !toggleCode()(view.state) }, children));
}
export function BulletListButton({ hint = 'BulletList\n' + bulletListKeys.toggle, hintPos = 'top', children = React.createElement(Icons.BulletListIcon, null), ...props }) {
    const view = useEditorViewContext();
    const onSelect = useCallback((e) => {
        e.preventDefault();
        if (toggleBulletList()(view.state, view.dispatch, view)) {
            if (view.dispatch) {
                view.focus();
            }
        }
    }, [view]);
    return (React.createElement(MenuButton, { ...props, hintPos: hintPos, onMouseDown: onSelect, hint: hint, isDisabled: !view.editable, isActive: queryIsBulletListActive()(view.state) &&
            !queryIsTodoListActive()(view.state) }, children));
}
export function OrderedListButton({ hint = 'OrderedList\n' + orderedListKeys.toggle, hintPos = 'top', children = React.createElement(Icons.OrderedListIcon, null), ...props }) {
    const view = useEditorViewContext();
    const onSelect = useCallback((e) => {
        e.preventDefault();
        if (toggleOrderedList()(view.state, view.dispatch, view)) {
            if (view.dispatch) {
                view.focus();
            }
        }
    }, [view]);
    return (React.createElement(MenuButton, { ...props, hintPos: hintPos, onMouseDown: onSelect, hint: hint, isDisabled: !view.editable, isActive: queryIsOrderedListActive()(view.state) }, children));
}
export function TodoListButton({ hint = 'TodoList\n' + bulletListKeys.toggleTodo, hintPos = 'top', children = React.createElement(Icons.TodoListIcon, null), ...props }) {
    const view = useEditorViewContext();
    const onSelect = useCallback((e) => {
        e.preventDefault();
        if (toggleTodoList()(view.state, view.dispatch, view)) {
            if (view.dispatch) {
                view.focus();
            }
        }
    }, [view]);
    return (React.createElement(MenuButton, { ...props, hintPos: hintPos, onMouseDown: onSelect, hint: hint, isDisabled: !view.editable, isActive: queryIsTodoListActive()(view.state) }, children));
}
export function HeadingButton({ level, hint = `Heading${level}\n` + headingKeys['toH' + level], hintPos = 'top', children = React.createElement(Icons.HeadingIcon, { level: level }), ...props }) {
    const view = useEditorViewContext();
    const onSelect = useCallback((e) => {
        e.preventDefault();
        if (toggleHeading(level)(view.state, view.dispatch, view)) {
            if (view.dispatch) {
                view.focus();
            }
        }
    }, [view, level]);
    return (React.createElement(MenuButton, { ...props, hintPos: hintPos, onMouseDown: onSelect, hint: hint, isActive: queryIsHeadingActive(level)(view.state), isDisabled: !view.editable || !toggleHeading(level)(view.state) }, children));
}
HeadingButton.propTypes = {
    level: PropTypes.number.isRequired,
};
export function ParagraphButton({ hint = `Paragraph\n` + paragraphKeys.convertToParagraph, hintPos = 'top', children = React.createElement(Icons.ParagraphIcon, null), ...props }) {
    const view = useEditorViewContext();
    const onSelect = useCallback((e) => {
        e.preventDefault();
        if (convertToParagraph()(view.state, view.dispatch, view)) {
            if (view.dispatch) {
                view.focus();
            }
        }
    }, [view]);
    return (React.createElement(MenuButton, { ...props, hintPos: hintPos, onMouseDown: onSelect, hint: hint, isActive: queryIsTopLevelParagraph()(view.state), isDisabled: !view.editable || !convertToParagraph()(view.state) }, children));
}
export function FloatingLinkButton({ hint = 'Link\n' + floatingMenuKeys.toggleLink, hintPos = 'top', children = React.createElement(Icons.LinkIcon, null), menuKey, }) {
    const view = useEditorViewContext();
    const onMouseDown = useCallback((e) => {
        e.preventDefault();
        const command = filter((state) => createLink('')(state), (_state, dispatch, view) => {
            if (dispatch) {
                toggleLinkSubMenu(menuKey)(view.state, view.dispatch, view);
                rafCommandExec(view, focusFloatingMenuInput(menuKey));
            }
            return true;
        });
        if (command(view.state, view.dispatch, view)) {
            if (view.dispatch) {
                view.focus();
            }
        }
    }, [view, menuKey]);
    return (React.createElement(MenuButton, { onMouseDown: onMouseDown, hint: hint, hintPos: hintPos, isActive: queryIsLinkActive()(view.state), isDisabled: !view.editable || !createLink('')(view.state) }, children));
}
FloatingLinkButton.propTypes = {
    menuKey: PropTypes.instanceOf(PluginKey).isRequired,
};
//# sourceMappingURL=MenuButtons.js.map